package com.sap.cloud.sample.helloworld.integrationtest;

import java.io.IOException;

import org.htmlunit.WebClient;
import org.htmlunit.html.HtmlPage;
import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Integration test using HtmlUnit.
 */
public class HelloWorldIntegrationTest {
    private static String serverUrl;

    /**
     * Take a provided server URL usually fed in from outside through the build process or default to the local server
     * as provided through Eclipse to run the integration test against.
     */
    @BeforeClass
    public static void setupSuite() {
        // Get integration test server URL
        serverUrl = System.getProperty("integration.test.server.url");
        if (serverUrl == null) {
            serverUrl = "http://localhost:8080";
        }
        System.out.println("Running against " + serverUrl);
    }

    /**
     * Call the main servlet and check that it contains the expected content.
     */
    @Test
    public void testHelloWorldServlet() throws IOException {
        // Call servlet
        try (final WebClient webClient = new WebClient()) {
            final HtmlPage page = webClient.getPage(serverUrl + "/hello-world/");
            final String pageAsText = page.asNormalizedText();
            Assert.assertTrue(pageAsText.contains("Hello World!"));
        }
    }
}
