package com.sap.cloud.sample.persistence.integrationtest;

import java.io.IOException;
import java.util.Random;

import org.htmlunit.WebClient;
import org.htmlunit.html.HtmlForm;
import org.htmlunit.html.HtmlInput;
import org.htmlunit.html.HtmlPage;
import org.htmlunit.html.HtmlSubmitInput;
import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;

/**
 * Integration test using HtmlUnit.
 */
public class PersistenceWithJDBCIntegrationTest {
    private static String serverUrl;
    private static String nameSupplement;

    /**
     * Take a provided server URL usually fed in from outside through the build process or default to the local server
     * as provided through Eclipse to run the integration test against.
     */
    @BeforeClass
    public static void setupSuite() {
        // Get integration test server URL
        serverUrl = System.getProperty("integration.test.server.url");
        if (serverUrl == null) {
            serverUrl = "http://localhost:8080";
        }
        System.out.println("Running against " + serverUrl);

        // Compute random name supplement that is appended and checked for later during the tests
        nameSupplement = Long.toHexString(new Random(System.currentTimeMillis()).nextLong());
    }

    /**
     * Call the main servlet and check that it contains the expected content.
     */
    @Test
    public void testPersistenceWithJDBCServlet() throws IOException {
        // Call servlet
        try (final WebClient webClient = new WebClient()) {
            final HtmlPage page = webClient.getPage(serverUrl + "/persistence-with-jdbc/");
            final String pageAsText = page.asNormalizedText();
            Assert.assertTrue(pageAsText.contains("Persistence with JDBC Sample!"));
        }
    }

    /**
     * Try to add one person and check that this person is found.
     */
    @Test
    public void testAddingPerson() throws IOException {
        // Call servlet
        try (final WebClient webClient = new WebClient()) {
            final HtmlPage page = webClient.getPage(serverUrl + "/persistence-with-jdbc/");
            // Fill out form and submit a person
            HtmlForm form = page.getForms().get(0);
            form.<HtmlInput>getInputByName("FirstName").type("John_" + nameSupplement);
            form.<HtmlInput>getInputByName("LastName").type("Doe_" + nameSupplement);
            final HtmlPage newPage = form.<HtmlSubmitInput>getInputByValue("Add Person").click();

            final String pageAsText = newPage.asNormalizedText();
            Assert.assertTrue(pageAsText.contains("John_" + nameSupplement));
            Assert.assertTrue(pageAsText.contains("Doe_" + nameSupplement));
        }
    }
}
